******************************
**			Table E.1		**
******************************
			
use gdp , clear
merge 1:1 c_code year using gini_new	
drop _merge

merge 1:m c_code year using meta_reall	
drop if _merge==1

* Columns 1 - 3 
global restrict " year<2001"
global xvars 	"only_pub only_man only_large only_small sep_hir "
global boots  	"vce(boot, r(1000))"	
global x 		"i.c_n  i.year  i.gap"


foreach lhs in gini prod{
local i = `i' +1
	foreach rhs in   gross net excess {
		reg `lhs' `rhs' $x  if $restrict , $boots
		est store `lhs'_`rhs'_all
		reg `lhs' `rhs' $x  if $restrict & sep_hir ==0 , $boots
		est store `lhs'_`rhs'_nosep_hir
		reg `lhs' `rhs' $x  if $restrict & sep_hir ==1 , $boots
		est store `lhs'_`rhs'_only_hir
	

		}
	}


* Productivity growth	
estimates table prod_gross_all prod_gross_nosep_hir prod_gross_only_hir , keep(gross) ///
				b(%9.2f) se(%9.2f) stat(r2 N)	
estimates table prod_net_all  prod_net_nosep_hir prod_net_only_hir, keep(net) ///
				b(%9.2f) se(%9.2f) stat(r2 N)				
estimates table prod_excess_all prod_excess_nosep_hir prod_excess_only_hir , keep(excess) ///
				b(%9.2f) se(%9.2f) stat(r2 N)				
				

* Gini index				
estimates table gini_gross_all gini_gross_nosep_hir gini_gross_only_hir, keep(gross) ///
				b(%9.2f) se(%9.2f) stat(r2 N)	
estimates table gini_net_all gini_net_nosep_hir gini_net_only_hir, keep(net) ///
				b(%9.2f) se(%9.2f) stat(r2 N)				
estimates table gini_excess_all gini_excess_nosep_hir gini_excess_only_hir, keep(excess) ///
				b(%9.2f) se(%9.2f) stat(r2 N)
				
				
* Columns 4-5 
foreach rhs in gross net excess{

reg `rhs' i.number i.gap $xvars if $restrict  
capture drop `rhs'_res
predict `rhs'_res if e(sample) , residuals

foreach lhs in prod gini {

reg  `lhs' `rhs'_res if $restrict , $boots
estimates store `lhs'_`rhs'_1

reg  `lhs' `rhs'_res  $x   if $restrict , $boots
estimates store `lhs'_`rhs'_2


}


}

* Productivity growth
estimates table prod_gross_1 prod_gross_2, keep(gross) b(%9.2f) se(%9.2f) stat(r2 N)	
estimates table prod_net_1 prod_net_2, keep(net) b(%9.2f) se(%9.2f) stat(r2 N)
estimates table prod_excess_1 prod_excess_2, keep(excess) b(%9.2f) se(%9.2f) stat(r2 N)

* Gini index
estimates table gini_gross_1 gini_gross_2, keep(gross) b(%9.2f) se(%9.2f) stat(r2 N)	
estimates table gini_net_1 gini_net_2, keep(net) b(%9.2f) se(%9.2f) stat(r2 N)
estimates table gini_excess_1 gini_excess_2, keep(excess) b(%9.2f) se(%9.2f) stat(r2 N)





* Columns 6-10 (Life in Transition Survey)
use flows_lits, clear

merge 1:1 c_code year using gdp 
drop _merge

merge 1:1 c_code year using gini_vshort 
drop _merge

replace lit = 0 if lit ==.
capture drop c_lit
egen c_lit = max(lit) , by(c_code)


* Countries absent in the LiTS
drop if c_code=="TKM"| c_code =="YUG" 
drop if c_n==.



* Countries & years for which we have information on flows
gen sep_hir = 0 
replace sep_hir=1 if c_code=="CZE" & year >1993 & year <1999
replace sep_hir=1 if c_code=="EST" & year >1989 & year <1995
replace sep_hir=1 if c_code=="POL" & year == 1994
replace sep_hir=1 if c_code=="RUS" & year >1990 & year <1999

* Countries for which we have some date
gen c_lit2 = 1 if c_code=="CZE" | c_code=="EST" | c_code=="POL" | c_code=="RUS" 
replace c_lit2 = 0 if c_lit2==.

gen gross = hire +sep
gen net = abs(hire-sep)
gen excess = gross - net



global rest_6 year >=1990 & year <2000 & sep_hir==1 & c_code !="SVK" 
global rest_7 year >=1990 & year <2000 & c_lit2==1 & c_code!="SVK"
global rest_8 year >=1990 & year <2000 & sep_hir==0 &  lit==1 & c_code !="SVK"
global rest_9 year >=1990 & year <2000 & sep_hir==0 &  c_lit==1 & c_code !="SVK"
global rest_10 year >=1990 & year <2000

xtset c_n year

foreach lhs in prod gini{
foreach rhs in gross net excess{

xi: xtreg `lhs' `rhs'  if $rest_6, fe  
est store `lhs'_`rhs'_6

xi: xtreg `lhs' `rhs'  if $rest_7, fe  
est store `lhs'_`rhs'_7

xi: xtreg `lhs' `rhs'  if $rest_8, fe   
est store `lhs'_`rhs'_8

xi: xtreg `lhs' `rhs'  if $rest_9, fe  
est store `lhs'_`rhs'_9

xi: xtreg `lhs' `rhs'   if $rest_10, fe 
est store `lhs'_`rhs'_10
}
}

* Productivity growth
estimates table prod_gross_6 prod_gross_7 prod_gross_8 prod_gross_9 prod_gross_10, keep(gross) b(%9.3f) se(%9.3f) stat(r2 N)	
estimates table prod_net_6 prod_net_7 prod_net_8 prod_net_9 prod_net_10, keep(net) b(%9.3f) se(%9.3f) stat(r2 N)
estimates table prod_excess_6 prod_excess_7 prod_excess_8 prod_excess_9 prod_excess_10, keep(excess) b(%9.3f) se(%9.3f) stat(r2 N)

* Gini index
estimates table gini_gross_6 gini_gross_7 gini_gross_8 gini_gross_9 gini_gross_10, keep(gross) b(%9.3f) se(%9.3f) stat(r2 N)	
estimates table gini_net_6 gini_net_7 gini_net_8 gini_net_9 gini_net_10, keep(net) b(%9.3f) se(%9.3f) stat(r2 N)
estimates table gini_excess_6 gini_excess_7 gini_excess_8 gini_excess_9 gini_excess_10, keep(excess) b(%9.3f) se(%9.3f) stat(r2 N)
